<?xml version="1.0"?> 

<!--                                                                        -->
<!-- Manifest Generator v1.0                                                -->
<!--                                                                        -->
<!-- Andrew Waugh                                                           -->
<!-- Copyright 2006 Public Record Office Victoria                           -->
<!--                                                                        -->
<!-- This stylesheet is provided as is with no warranty as to fitness for   -->
<!-- any purpose. In particular, we do not warrant that use of this tool    -->
<!-- will produce valid manifests that PROV will accept for loading into    -->
<!-- the digital archive.                                                   -->
<!--                                                                        -->
<!-- Known limitations on this tool include:                                -->
<!-- * It does not enforce the limits on the lengths of certain elements    -->
<!--                                                                        -->

<xsl:stylesheet
	xmlns:xsl="http://www.w3.org/1999/XSL/Transform"
	xmlns:dam="http://www.prov.vic.gov.au/digitalarchive/"
	xmlns:xsi="http://www.w3.org/2001/XMLSchema-instance"
	xmlns:naa="http://www.naa.gov.au/recordkeeping/control/rkms/contents.html"
	xmlns:vers="http://www.prov.vic.gov.au/gservice/standard/pros99007.htm"
	exclude-result-prefixes="xsl xsi dam naa vers"
	version="1.0">
  <xsl:output method="xml" omit-xml-declaration="yes" indent="no"
	cdata-section-elements="dam:veo_classification dam:file_identifier dam:vers_record_identifier dam:veo_title"/>

<xsl:template match="/">
	<xsl:apply-templates select="vers:VERSEncapsulatedObject/vers:SignedObject/vers:ObjectContent"/>
</xsl:template>

<xsl:template match="vers:ObjectContent">
	<xsl:apply-templates select="vers:Record/vers:RecordMetadata"/>
	<xsl:apply-templates select="vers:File/vers:FileMetadata"/>
	<xsl:apply-templates select="vers:ModifiedVEO/vers:RevisedVEO/vers:SignedObject/vers:ObjectContent"/>
</xsl:template>

<xsl:template match="vers:RecordMetadata|vers:File/vers:FileMetadata">
	<xsl:apply-templates select="vers:VEOIdentifier"/>
	<xsl:choose>
	<xsl:when test="naa:Title">
		<xsl:apply-templates select="naa:Title/naa:TitleWords"/>
	</xsl:when>
	<xsl:otherwise>
		<dam:veo_title>
		No Title
		</dam:veo_title>
	</xsl:otherwise>
	</xsl:choose>
	<xsl:choose>
	<xsl:when test="naa:Function">
		<dam:veo_classification>
		<xsl:apply-templates select="naa:Function"/>
		</dam:veo_classification>
	</xsl:when>
	<xsl:when test="vers:Subject">
		<dam:veo_classification>
		<xsl:apply-templates select="vers:Subject"/>
		</dam:veo_classification>
	</xsl:when>
	<xsl:otherwise>
		<dam:veo_classification>
		No classification
		</dam:veo_classification>
	</xsl:otherwise>
	</xsl:choose>
	<dam:veo_access_category>
	Not specified
	</dam:veo_access_category>
	<xsl:apply-templates select="naa:Disposal/naa:Sentence"/>
	<xsl:apply-templates select="naa:Date"/>
	<xsl:apply-templates select="vers:Date"/>
</xsl:template>

<xsl:template match="vers:ModifiedVEO">
	<xsl:apply-templates select="vers:RevisedVEO/vers:SignedObject/vers:ObjectContent"/>
</xsl:template>

<xsl:template match="vers:VEOIdentifier">
	<xsl:apply-templates select="vers:FileIdentifier"/>
	<xsl:choose>
	<xsl:when test="vers:VERSRecordIdentifier">
		<xsl:apply-templates select="vers:VERSRecordIdentifier"/>
	</xsl:when>
	<xsl:otherwise>
	<dam:vers_record_identifier xsi:nil="true"/>
	</xsl:otherwise>
	</xsl:choose>
</xsl:template>

<xsl:template match="vers:FileIdentifier">
	<dam:file_identifier><xsl:apply-templates select="vers:Text"/></dam:file_identifier>
</xsl:template>

<xsl:template match="vers:VERSRecordIdentifier">
	<dam:vers_record_identifier><xsl:apply-templates select="vers:Text"/></dam:vers_record_identifier>
</xsl:template>

<xsl:template match="naa:TitleWords">
	<dam:veo_title><xsl:value-of select="normalize-space(.)"/></dam:veo_title>
</xsl:template>

<xsl:template match="naa:Function">
	<xsl:value-of select="naa:FunctionDescriptor"/>
	<xsl:value-of select="naa:ActivityDescriptor"/>
	<xsl:value-of select="naa:ThirdLevelDescriptor"/>
</xsl:template>

<xsl:template match="vers:Subject">
		(
		<xsl:value-of select="normalize-space(vers:KeywordLevel)"/>
		<xsl:text> </xsl:text>
		<xsl:apply-templates select="vers:Keyword"/>
		<xsl:apply-templates select="vers:Subject"/>
		)
</xsl:template>

<xsl:template match="vers:Keyword">
	<xsl:value-of select="normalize-space(.)"/>
</xsl:template>

<xsl:template match="vers:RightsManagement">
	<xsl:choose>
	<xsl:when test="naa:AccessStatus">
		<dam:veo_access_category>
		<xsl:apply-templates select="naa:AccessStatus"/>
		</dam:veo_access_category>
	</xsl:when>
	<xsl:otherwise>
		<dam:veo_access_category>
		None
		</dam:veo_access_category>
	</xsl:otherwise>
	</xsl:choose>
</xsl:template>

<xsl:template match="naa:Sentence">
	<dam:veo_disposal_authority><xsl:value-of select="normalize-space(.)"/></dam:veo_disposal_authority>
</xsl:template>

<xsl:template match="naa:Date">
	<dam:veo_date_range>
	<dam:veo_start_date xsi:nil="true"/>
	<dam:veo_end_date><xsl:value-of select="normalize-space(naa:DateTimeRegistered)"/></dam:veo_end_date>
	</dam:veo_date_range>
</xsl:template>

<xsl:template match="vers:Date">
	<dam:veo_date_range>
	<dam:veo_start_date><xsl:value-of select="normalize-space(naa:DateTimeRegistered)"/></dam:veo_start_date>
	<xsl:choose>
	<xsl:when test="vers:DateTimeClosed">
	<dam:veo_end_date><xsl:value-of select="normalize-space(vers:DateTimeClosed)"/></dam:veo_end_date>
	</xsl:when>
	<xsl:otherwise>
	<dam:veo_end_date xsi:nil="true"/>
	</xsl:otherwise>
	</xsl:choose>
	</dam:veo_date_range>
</xsl:template>

<xsl:template match="vers:Text">
	<xsl:value-of select="normalize-space(.)"/>
</xsl:template>
</xsl:stylesheet>
